==> dhall-docs-1.0.12-156-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-AjXMa3Eyn2wBbGBx6iGiCu
key:                  dhall-docs-1.0.12-AjXMa3Eyn2wBbGBx6iGiCu
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  b94b768991eeba0850928fae7ca18663
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-AjXMa3Eyn2wBbGBx6iGiCu
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-GXeKCI4bd7n6SsJ2qNUYhy
    dhall-1.42.3-1NGBipCptk29VSvs5IrIkw directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    mmark-0.0.7.6-5pjQPOX7BlV9LpnbxuWbW1 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
    path-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-docs-1.0.12-157-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-docs
version:              1.0.12
visibility:           public
id:                   dhall-docs-1.0.12-LZQh7fK7UjdHGVxJdlfHJF
key:                  dhall-docs-1.0.12-LZQh7fK7UjdHGVxJdlfHJF
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  d7ae8768c9b11f2ef7ac42a89623834a
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-docs-1.0.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.12-LZQh7fK7UjdHGVxJdlfHJF
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-Dwd5n4mSUH32rjuqPFOreR
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha256-0.11.102.1-GXeKCI4bd7n6SsJ2qNUYhy
    dhall-1.42.3-KXmenYTki91GraQt2ymkdK directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    lens-family-core-2.1.3-ATkyQy7CaRL9XkLMxregni
    lucid-2.11.20250303-mIfSyYQWD8L0pbvgCqca8
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    mmark-0.0.7.6-5pjQPOX7BlV9LpnbxuWbW1 mtl-2.3.1
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
    path-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
    prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
